==> haskell-success-0.2.6-278-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 success
version:              0.2.6
visibility:           public
id:                   success-0.2.6-2iYc0FaJnOBCsbc6Dd4Ar4
key:                  success-0.2.6-2iYc0FaJnOBCsbc6Dd4Ar4
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/success 
synopsis:
    A version of Either specialised for encoding of success or failure

description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.

category:             Data, Failure
abi:                  8d13d905d99d212adf2aba2eaff24ae3
exposed:              True
exposed-modules:      Success.Impure Success.Pure
import-dirs:          /usr/lib/ghc-9.2.8/site-local/success-0.2.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-success
hs-libraries:         HSsuccess-0.2.6-2iYc0FaJnOBCsbc6Dd4Ar4
depends:
    base-4.16.4.0 monad-control-1.0.3.1-I8GZevPHGG9CaaoPHICfGK
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-L226RdjYZ7s6DhRd0WmCwN

haddock-interfaces:   /usr/share/doc/haskell-success/html/success.haddock
haddock-html:         /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-success-0.2.6-306.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 success
version:              0.2.6
visibility:           public
id:                   success-0.2.6-DMtzGPCCspvJZsGJ4w6GlU
key:                  success-0.2.6-DMtzGPCCspvJZsGJ4w6GlU
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/success 
synopsis:
    A version of Either specialised for encoding of success or failure

description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.

category:             Data, Failure
abi:                  936c14556ccf3084e6c88891b8e577c5
exposed:              True
exposed-modules:      Success.Impure Success.Pure
import-dirs:          /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-success
hs-libraries:         HSsuccess-0.2.6-DMtzGPCCspvJZsGJ4w6GlU
depends:
    base-4.17.2.1 monad-control-1.0.3.1-CU0oSebqH0K53geyhZCKTM
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-Gpx2WMc051hBRdn2HnKilA

haddock-interfaces:   /usr/share/doc/haskell-success/html/success.haddock
haddock-html:         /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
